"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTargetHostnameComponent = void 0;
const logSymbols = require("log-symbols");
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_hostname_check_component_1 = require("./target-hostname-check-component");
const util_1 = require("../../util");
async function getTargetHostnameComponent(props) {
    const { yes, device } = props;
    const targetHostname = device.host_name !== '' ? device.host_name : props.targetHostname;
    if (yes && !targetHostname) {
        throw new alwayscli_1.CliUsageError((0, util_1.RequiredWithYesMessage)('hostname'));
    }
    if (device.host_name !== '' && props.targetHostname) {
        (0, util_1.echo)(`${logSymbols.warning} Input for targetHostname will be ignored.`);
    }
    if (device.mode === 'production') {
        // Support prompting for hostname for production (provisioned) devices only
        if (!targetHostname) {
            return await (0, target_hostname_check_component_1.targetHostnameCheckComponent)({
                prompt: true
            });
        }
    }
    await (0, target_hostname_check_component_1.targetHostnameCheckComponent)({
        targetHostname,
        prompt: false
    });
    return targetHostname;
}
exports.getTargetHostnameComponent = getTargetHostnameComponent;
//# sourceMappingURL=get-target-hostname-component.js.map