"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkForDockerComposeComponent = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const util_1 = require("../../util");
async function checkForDockerComposeComponent(spawner) {
    const spinner = (0, util_1.Spinner)('Check for Docker Compose');
    try {
        await spawner.run({ exe: 'docker-compose', args: ['--version'] });
        spinner.succeed();
    }
    catch (ex) {
        spinner.fail('Command "docker-compose --version" failed');
        (0, util_1.echo)((0, util_1.stringifyError)(ex));
        (0, util_1.echo)(`Please install docker-compose on your target system or verify the existing installation if there is one.`);
        (0, util_1.echo)();
        (0, util_1.echo)('To install on an ARM-based device, run:');
        (0, util_1.echo)();
        (0, util_1.echo)('  pip3 install docker-compose');
        (0, util_1.echo)('  sudo ln -s /home/<user>/.local/bin/docker-compose /usr/local/bin/docker-compose');
        (0, util_1.echo)();
        (0, util_1.echo)('To install on x86 systems, see:');
        (0, util_1.echo)();
        (0, util_1.echo)('  https://docs.docker.com/compose/install/');
        (0, util_1.echo)();
        throw new alwayscli_1.CliTerseError('Failed to run "docker-compose --version"');
    }
}
exports.checkForDockerComposeComponent = checkForDockerComposeComponent;
//# sourceMappingURL=check-for-docker-compose-component.js.map