"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeModelFromProject = exports.addModelToProject = exports.fetchProjectModels = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const util_1 = require("../../util");
const project_1 = require("../../core/project");
const infrastructure_1 = require("../../infrastructure");
async function fetchProjectModels() {
    const projectId = await (0, project_1.getCurrentProjectId)();
    return await (0, infrastructure_1.CliRpcClient)().getProjectModels({
        project_id: projectId
    });
}
exports.fetchProjectModels = fetchProjectModels;
async function addModelToProject(modelId) {
    const projectId = await (0, project_1.getCurrentProjectId)();
    try {
        await (0, infrastructure_1.CliRpcClient)().addProjectModel({
            project_id: projectId,
            model_id: modelId
        });
    }
    catch (error) {
        util_1.logger.error((0, util_1.stringifyError)(error));
        if (error.code !== 'DUPLICATE_MODEL_ADDED_TO_PROJECT') {
            throw new alwayscli_1.CliTerseError('Failed to add model to project!');
        }
    }
}
exports.addModelToProject = addModelToProject;
async function removeModelFromProject(modelId) {
    const projectId = await (0, project_1.getCurrentProjectId)();
    try {
        await (0, infrastructure_1.CliRpcClient)().deleteProjectModel({
            project_id: projectId,
            model_id: modelId
        });
    }
    catch (error) {
        util_1.logger.error((0, util_1.stringifyError)(error));
        throw new alwayscli_1.CliTerseError('Failed to remove model from project!');
    }
}
exports.removeModelFromProject = removeModelFromProject;
//# sourceMappingURL=models.js.map