"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTargetHardwareType = exports.TARGET_HARDWARE_OPTIONS = exports.targetHardware = exports.TargetHardware = void 0;
const t = require("io-ts");
const alwayscli_1 = require("@alwaysai/alwayscli");
const util_1 = require("../../util");
exports.TargetHardware = (0, util_1.keyMirror)({
    'jetson-jp5.1': null,
    'jetson-jp5.1.1': null,
    armv7hf: null,
    aarch64: null,
    amd64: null,
    'x86-trt-22.12': null,
    'x86-trt-23.04': null,
    'hailo-amd64': null
});
exports.targetHardware = t.keyof(exports.TargetHardware);
exports.TARGET_HARDWARE_OPTIONS = Object.keys(exports.TargetHardware);
async function getTargetHardwareType(props) {
    const { targetHostname } = props;
    const spawner = targetHostname
        ? (0, util_1.SshSpawner)({ targetHostname })
        : (0, util_1.JsSpawner)({ path: '.' });
    let targetHardware;
    const arch = await spawner.run({
        exe: 'uname',
        args: ['-m']
    });
    const kernel = await spawner.run({
        exe: 'uname',
        args: ['-r']
    });
    if (kernel.includes('tegra') || kernel.includes('l4t')) {
        const l4tVersion = await (0, util_1.getL4TVersion)({ spawner });
        if (l4tVersion === null) {
            throw new alwayscli_1.CliTerseError('JetPack version not found!');
        }
        switch (l4tVersion) {
            case '35.2.1':
                targetHardware = 'jetson-jp5.1';
                break;
            case '35.3.1':
                targetHardware = 'jetson-jp5.1.1';
                break;
            default:
                throw new alwayscli_1.CliTerseError(`L4T version ${l4tVersion} not supported!`);
        }
    }
    else if (arch.includes('armv7')) {
        targetHardware = 'armv7hf';
    }
    else if (arch.includes('aarch64') ||
        arch.includes('armv8') ||
        arch.includes('arm64')) {
        targetHardware = 'aarch64';
    }
    else if (arch.includes('amd64') || arch.includes('x86_64')) {
        targetHardware = 'amd64';
    }
    else {
        throw new alwayscli_1.CliTerseError(`Target hardware (${arch}) not supported!`);
    }
    return targetHardware;
}
exports.getTargetHardwareType = getTargetHardwareType;
//# sourceMappingURL=get-target-hardware-type.js.map