"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.modelPackageCloudClient = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const node_fetch_1 = require("node-fetch");
const cloud_api_1 = require("@alwaysai/cloud-api");
const alwayscli_1 = require("@alwaysai/alwayscli");
const tar = require("tar");
const tempy = require("tempy");
const util_1 = require("util");
const model_json_file_1 = require("./model-json-file");
const util_2 = require("../../util");
const infrastructure_1 = require("../../infrastructure");
const model_id_1 = require("./model-id");
exports.modelPackageCloudClient = {
    async download(id, version) {
        try {
            const { uuid } = await (0, infrastructure_1.CliRpcClient)().getModelVersion({ id, version });
            const modelPackageUrl = ModelPackageUrl(uuid);
            const authorizationHeader = await (0, infrastructure_1.CliAuthenticationClient)().getAuthorizationHeader();
            const response = await (0, node_fetch_1.default)(modelPackageUrl, {
                method: 'GET',
                headers: Object.assign(Object.assign({}, authorizationHeader), { 'Content-Length': '0' })
            });
            await (0, util_2.throwIfNotOk)(response);
            return response.body;
        }
        catch (exception) {
            util_2.logger.error((0, util_2.stringifyError)(exception));
            throw new alwayscli_1.CliTerseError(`The model ${id} is not associated with your account!`);
        }
    },
    async publish(dir = process.cwd()) {
        const modelJson = (0, model_json_file_1.ModelJsonFile)(dir).read();
        const rpcClient = (0, infrastructure_1.CliRpcClient)();
        const { uuid } = await rpcClient.createModelVersion(modelJson);
        const authorizationHeader = await (0, infrastructure_1.CliAuthenticationClient)().getAuthorizationHeader();
        // Ensure top level directory matches model name
        const { name } = model_id_1.ModelId.parse(modelJson.id);
        const tmpDir = tempy.directory({ prefix: 'alwaysai' });
        const tmpModelDir = (0, path_1.join)(tmpDir, name);
        await (0, util_2.JsSpawner)().mkdirp(tmpModelDir);
        await (0, util_2.copyFiles)((0, util_2.JsSpawner)({ path: dir }), (0, util_2.JsSpawner)({ path: tmpModelDir }));
        const modelPackagePath = tempy.file();
        await tar.create({ cwd: tmpDir, gzip: true, file: modelPackagePath }, [
            name
        ]);
        await (0, util_2.JsSpawner)().rimraf(tmpDir);
        const stats = await (0, util_1.promisify)(fs_1.stat)(modelPackagePath);
        const modelPackageStream = (0, fs_1.createReadStream)(modelPackagePath);
        const response = await (0, node_fetch_1.default)(ModelPackageUrl(uuid), {
            method: 'PUT',
            headers: Object.assign({ 'Content-Type': 'application/gzip', 'Content-Length': stats.size.toString() }, authorizationHeader),
            body: modelPackageStream
        });
        await (0, util_2.throwIfNotOk)(response);
        await rpcClient.finalizeModelVersion(uuid);
        return uuid;
    }
};
function ModelPackageUrl(uuid) {
    const cloudApiUrl = (0, cloud_api_1.CloudApiUrl)((0, infrastructure_1.getSystemId)());
    return `${cloudApiUrl}${cloud_api_1.CLOUD_API_MODEL_VERSION_PACKAGES_PATH}/${uuid}`;
}
//# sourceMappingURL=model-package-cloud-client.js.map