"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appAnalyticsCliBranch = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const logSymbols = require("log-symbols");
const app_1 = require("../../core/app");
const util_1 = require("../../util");
const show = (0, alwayscli_1.CliLeaf)({
    name: 'show',
    description: `Show your current application analytics configuration`,
    action() {
        const appCfgFile = (0, app_1.AppJsonFile)();
        const appCfg = appCfgFile.read();
        const analytics = appCfg.analytics ? appCfg.analytics : {};
        (0, util_1.echo)(analytics);
    }
});
function printAnalytics(opts) {
    const { changed, analytics } = opts;
    const log = changed
        ? `${logSymbols.success} Updated analytics configuration.`
        : `${logSymbols.warning} Analytics configuration not updated.`;
    (0, util_1.echo)(log);
    (0, util_1.echo)(`analytics: ${JSON.stringify(analytics || {}, null, 2)}`);
}
const enableCloudPublish = (0, alwayscli_1.CliLeaf)({
    name: 'enable-cloud-publish',
    description: `Enable analytics cloud publish`,
    action() {
        const appCfgFile = (0, app_1.AppJsonFile)();
        const result = appCfgFile.update((appCfg) => {
            const analytics = appCfg.analytics || {};
            appCfg.analytics = Object.assign(Object.assign({}, analytics), { enable_cloud_publish: true });
        });
        printAnalytics({
            changed: result.changed,
            analytics: appCfgFile.read().analytics
        });
    }
});
const disableCloudPublish = (0, alwayscli_1.CliLeaf)({
    name: 'disable-cloud-publish',
    description: `Disable analytics cloud publish`,
    action() {
        const appCfgFile = (0, app_1.AppJsonFile)();
        const result = appCfgFile.update((appCfg) => {
            if (appCfg.analytics) {
                appCfg.analytics.enable_cloud_publish = false;
            }
        });
        printAnalytics({
            changed: result.changed,
            analytics: appCfgFile.read().analytics
        });
    }
});
const enableFilePublish = (0, alwayscli_1.CliLeaf)({
    name: 'enable-file-publish',
    description: `Enable analytics file publish`,
    action() {
        const appCfgFile = (0, app_1.AppJsonFile)();
        const result = appCfgFile.update((appCfg) => {
            if (!appCfg.analytics) {
                appCfg.analytics = { enable_file_publish: true };
            }
            else {
                appCfg.analytics.enable_file_publish = true;
            }
        });
        printAnalytics({
            changed: result.changed,
            analytics: appCfgFile.read().analytics
        });
    }
});
const disableFilePublish = (0, alwayscli_1.CliLeaf)({
    name: 'disable-file-publish',
    description: `Disable analytics file publish`,
    action() {
        const appCfgFile = (0, app_1.AppJsonFile)();
        const result = appCfgFile.update((appCfg) => {
            if (appCfg.analytics) {
                appCfg.analytics.enable_file_publish = false;
            }
        });
        printAnalytics({
            changed: result.changed,
            analytics: appCfgFile.read().analytics
        });
    }
});
exports.appAnalyticsCliBranch = (0, alwayscli_1.CliBranch)({
    name: 'analytics',
    description: `Show and set application analytics configuration values`,
    subcommands: [
        show,
        enableCloudPublish,
        disableCloudPublish,
        enableFilePublish,
        disableFilePublish
    ]
});
//# sourceMappingURL=analytics.js.map