"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.testSuiteFuncs = exports.config = void 0;
const rimraf_1 = require("rimraf");
const alwayscli_1 = require("@alwaysai/alwayscli");
const constants_1 = require("../../constants");
const util_1 = require("../../util");
const infrastructure_1 = require("../../infrastructure");
const environment_1 = require("../../environment");
const paths_1 = require("../../paths");
const logSymbols = require("log-symbols");
const show = (0, alwayscli_1.CliLeaf)({
    name: 'show',
    description: `Show your current "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME}" configuration`,
    action() {
        if (environment_1.ALWAYSAI_SYSTEM_ID) {
            (0, util_1.echo)(`${logSymbols.warning} System ID is overridden by environment variable "ALWAYSAI_SYSTEM_ID"`);
        }
        return { systemId: (0, infrastructure_1.getSystemId)() };
    }
});
const set = (0, alwayscli_1.CliLeaf)({
    name: 'set',
    description: `Set an "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME}" configuration value`,
    namedInputs: {
        systemId: (0, alwayscli_1.CliOneOfInput)({ values: constants_1.SYSTEM_IDS, required: true })
    },
    action(_, { systemId }) {
        if (environment_1.ALWAYSAI_SYSTEM_ID) {
            (0, util_1.echo)(`${logSymbols.warning} System ID is overridden by environment variable "ALWAYSAI_SYSTEM_ID"`);
        }
        return (0, infrastructure_1.setSystemId)(systemId);
    }
});
function purgeConfig(path) {
    const spinner = (0, util_1.Spinner)('Removing the configuration files');
    try {
        rimraf_1.rimraf.sync(path);
        spinner.succeed();
    }
    catch (exception) {
        spinner.fail();
        throw exception;
    }
}
const purge = (0, alwayscli_1.CliLeaf)({
    name: 'purge',
    description: 'Purge config files and credentials.',
    action(_) {
        purgeConfig(paths_1.LOCAL_AAI_CFG_DIR);
    }
});
exports.config = (0, alwayscli_1.CliBranch)({
    name: 'config',
    hidden: !environment_1.ALWAYSAI_SHOW_HIDDEN,
    description: `Show, set, or purge "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME}" configuration values`,
    subcommands: [show, set, purge]
});
exports.testSuiteFuncs = {
    purgeConfig
};
//# sourceMappingURL=index.js.map