"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const winston = require("winston");
require("winston-daily-rotate-file");
const path = require("path");
const paths_1 = require("../paths");
const environment_1 = require("../environment");
const LOG_LEVEL = environment_1.ALWAYSAI_LOG_LEVEL || 'info';
const transports = environment_1.ALWAYSAI_LOG_TO_CONSOLE
    ? [new winston.transports.Console({ level: LOG_LEVEL })]
    : [
        new winston.transports.DailyRotateFile({
            filename: path.join(paths_1.AAI_DIR, 'cli-logs', 'cli-logs.txt'),
            maxSize: '5m',
            maxFiles: '2d'
        })
    ];
exports.logger = winston.createLogger({
    level: LOG_LEVEL,
    format: winston.format.combine(winston.format.timestamp(), winston.format.errors({ stack: true }), winston.format.splat(), winston.format.simple(), winston.format.printf(({ timestamp = '', level = '', message = '' }) => {
        return `[${timestamp}] ${level}: ${message}`;
    })),
    transports
});
exports.logger.info(`Initialized logger with log level: ${LOG_LEVEL}`);
//# sourceMappingURL=logger.js.map