"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Spinner = void 0;
const ora = require("ora");
const environment_1 = require("../environment");
const audit_1 = require("./audit");
function Spinner(message) {
    (0, audit_1.audit)(`Spinner: ${message}`);
    let spinner;
    if (environment_1.NODE_ENV === 'test') {
        spinner = {
            fail(message) {
                console.log(`Spinner test: ${message}`);
            },
            succeed(message) {
                console.log(`Spinner test: ${message}`);
            },
            warn(message) {
                console.log(`Spinner test: ${message}`);
            },
            setMessage(message) {
                console.log(`Spinner test: ${message}`);
            }
        };
    }
    else {
        const oraSpinner = ora({ text: message, discardStdin: false }).start();
        spinner = {
            fail(message) {
                oraSpinner.fail(message);
            },
            warn(message) {
                oraSpinner.warn(message);
            },
            succeed(message) {
                oraSpinner.succeed(message);
            },
            setMessage(message) {
                oraSpinner.text = message;
            }
        };
    }
    return spinner;
}
exports.Spinner = Spinner;
//# sourceMappingURL=spinner.js.map